#!/usr/bin/wish
#
#*helpbegin*
#                                   tk_gnupod
#                                   =========
#
#                                  Version 0.1   
#                                Uwe Berger; 2006
#                               
#                    
#Inhalt:
#=======
#         1. Was ist tk_gnupod?
#         2. Installation/Voraussetzungen
#         3. Handhabung
#         4. Kontakt
#         
#         
#1. Was ist tk_gnupod?
#---------------------
#Bei tk_gnupod handelt es sich um ein grafisches Frontend zu den Kommandozeilentools gnupod (http://www.gnu.org/software/gnupod/). Mit Hilfe von gnupod ist die "Administration" eines iPod, also im wesendlichen das Kopieren und Loeschen von Musik auf dem Selbigen, moeglich. Welche der iPod-Modelle dabei unterstuetzt werden, ist der jeweiligen Dokumentation zu entnehmen. Im Besonderen werden dabei folgende gnupod-Befehle (zu denen es jeweils auch manpages gibt!) durch tk_gnupod grafisch unterstuetzt:
#
#   gnpod_search   -> Auflisten und Loeschen des iPod-Inhaltes
#   gnupod_addsong -> Musiktitel auf den iPod kopieren
#   mktunes        -> generieren der iTunesDB
#   tunes2pod      -> generieren der gnupodDB aus iTunesDB
#
#
#2. Voraussetzungen/Installation
#-------------------------------
#tk_gnupod ist in der Scriptsprache TCL und der grafischen Erweiterung TK geschrieben. Folgende Pakete/Programme sind zum Betrieb von tk_gnupod notwendig:
#
#   TCL/TK  -> die Scriptsprache plus grafischer Erweiterung
#   BWidget -> TK-Erweiterung, tk_gnupod verwendet einige der Widgets
#   gnupod  -> die Kommando-Tools
#   df      -> sollte eigentlich zu jedem Linux-Basispaket gehoeren
#   
#Unter Debian existieren entsprechende Pakete. Bei anderen Distributionen sieht es wahrscheinlich ähnlich aus.
#
#Die Installation von tk_gnupot gestaltet sich realiv einfach. Eigentlich sind alle mitgelieferten Dateien nur in ein Verzeichnis zu kopieren. Die Datei tk_gnupod.tcl ist als startbar zu kennzeichnen. Der Start des Programmes tk_gnupod erfolgt am Besten aus dem Verzeichnis, in dem auch das Programm liegt (die Bilddateien der Icon, diese README und die Konfigurationsdatei werden im aktuellen Verzeichnis erwartet!). 
#
#
#3. Handhabung
#-------------
#Es wurde versucht, die Oberflaeche intuitiv zu gestalten. Allerdings laesst sich ueber Geschmack streiten...
#
#Vor dem Start des Programmes sollte der iPod in das Dateisystem eingebunden (mount...) sein. Das Mount-Verzeichnis ist auch in der Konfiguration (entsprechende Notebook-Seite in tk_gnupod) anzugeben. Handelt es sich bei dem angegebenen Verzeichnis um keinen iPod, erscheint beim Start (bzw. Neueinlesen des iPod) eine entsprechende Fehlermeldung. Desweiteren kann auf der Konfigurationsseite das, bei Start von tk_gnupod zuerst angezeigte Verzeichnis (am sinnvollsten das Verzeichnis, in dem die Musikdateien liegen) angegeben werden.
#
#Vor dem ersten Aufruf von tk_gnupod (und nach dem Einbinden des iPod in den Verzeichnisbaum) sollte der iPod fuer die Verwendung von gnupod vorbereitet werden. Dazu ist einmalig das Kommando gnupod_INIT -m <ipod_verzeichnis> auf Kommandozeilenebene gestartet werden. Keine Angst, es wird lediglich ein weiteres Verzeichnis auf dem iPod angelegt.
#
#Saemtliche wichtigen Bildschirmelemente von tk_gnupod sind mit sogenannten Sprechblasenhilfen versehen. Verweilt man etwas laenger auf einem Element, erscheint eine entsprechende Hilfe. Diese Sprechblasen sind auf der Konfigurationsseite abschaltbar.
#
#Die Oberflaeche von tk_gnupod ist folgendermassen gestaltet:
#
#Linke Haelfte -> Das Dateisystem, in dem, wie gewohnt, mit Doppelklick weiter "abgetaucht" werden kann. Mit dem zweiten der beiden Button oben links kann eine Verzeichnisstufe hoeher navigiert werden. Die Eintraege in Verzeichnis-/Dateiliste sind selektierbar (auch mehrere gleichzeitig). Mit dem Button rechts oben in der linken Bildschirmhaelfte koennen die Dateien auf den iPod kopiert werden. Dabei wird zur Sicherheit zwischen dem Umfang der angewaehlten Objekte und dem noch verfuegbaren Platz auf dem iPod verifiziert. Im Fehlerfall wird eine entsprechende Meldung angezeigt und das Kopieren findet nicht statt. 
#
#Rechte Haelfte -> Hier wird der Inhalt des iPod angezeigt. Mit den 3 Button in dieser Haelfte links oben kann zwischen Titel-/Alben-/Interpretensicht umgeschaltet werden. Auch hier ist wieder eine (Mehrfach-)Selektion der Eintraege moeglich. Der erste der beiden Button rechts oben loescht die selektierten Elemente auf dem iPod. Der zweite Button loescht den gesamten Musikinhalt.
#
#Der Fortschritt der Kopier- und Loeschvorgaenge auf dem iPod werden in der unteren Statuszeile angezeigt.
#
#Zum Abschluss ist der iPod unbedingt manuell aus dem Dateisystem auszuhaengen (umount)! Dies erfolgt nicht durch tk_gnupod!
#
#
#4. Kontakt
#----------
#Bei Fragen und Anregungen einfach eine E-Mail an bergeruw@gmx.net
#
#
#Have fun!
#
#*helpend*
#lappend auto_path [file join [pwd] BWidget-1.4.1]
package require BWidget 

option add *Dialog.msg.font {helvetica 12 bold}

# Konfig-Variablen...
set home_dir "/home/bergeruw/_mp3/"
set ipod_dir "/mnt/ipod/"
set balloon_sichtbar 1


set script_dir [file dirname [info script]]
set config_file "$env(HOME)/.tk_gnupod"
set readme_file [info script]


# interne Variablen...
set akt_dir $home_dir
set parent_dir $akt_dir

# Icons
set icon_cd {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1P/isf/Ujv/Ga/+4SP+qJf+qANySALl6AJZiAHNKAFAyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSj4+PjIyMiYmJhoaGg4ODv/78KCgpICAgP8AAAD/
AP//AAAA//8A/wD//////yH5BAEAAP4ALAAAAAAUABQAAAj+AP0JFHjuHLp1
7dqtQ1dwoEOC6+DJAyBvojx46849JPgOgLuF5swddAfgnUaH5zqqgwQJFLmX
5capK3nSX0oA6/aBavmSnDhy/9bRtClU3QMGOl36BPrv38yM5+C9I4Hh6L5y
Bcs1/UfOnDt4BuWtI0H1wbl069alO8d1XLl18g4CQIehbrl0TMmlK/eTHDqc
7eSZ63lu3T8AAIKe62lOXkLBhA0jVszYsVB0L8Xdzbu3Loa/C8Uu/Xc27doH
GMjCZQjP3Tim/7CeK7ePAWoSXwsW3bqUHChQtR881XjTcG/fLfcJNTnwprrB
PXdCmskcZceP6EKOHLqxsESKFjEL1uxuEKFChuP9BQQAOw==}

set icon_check {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1P/isf/Ujv/Ga/+4SP+qJf+qANySALl6AJZiAHNKAFAyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSv//////////////////////////////////////
/////////////////////yH5BAEAAP8ALAAAAAAUABQAAAh9AP8JHEiwoMGD
CBMqdAcAnkKD8AC8avhwYMRWumBRfHhR16tXGv+ti+gOIgCMHzW6Gwlg1UaB
HVNSjKhLV6uNMUFuBADro82GOTU6FMiw5yub1aqh1DnUIk+frZYKPRjRaE2Z
TU0axcrxKdOK/6pOBRsWwEuy7kqSXcu2YEAAOw==}

set icon_dataextract {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1P/isf/Ujv/Ga/+4SP+qJf+qANySALl6AJZiAHNKAFAyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSj4+PjIyMiYmJv//////////////////////////
/////////////////////yH5BAEAAP8ALAAAAAAUABQAAAjbAP8JHPgv3bp2
8hLKa7cuHcGH7+LJA0ChQgUKAOTFe/fw37l38yhMmCChpISRFOa9O0eQXUiS
JmNOSMmuJYCXMEuinAeg5kB3ACrEu0ihaFGhFQC4IwjUIkYAUKFWTLr0Z1CR
MXVWVDoQHtSLJCM4eBDh5NaqXgkFBSthbNmZVP+lNRQ1qgSyZqnONcS3L0W8
cJV6TcQ3kWHDf9+elQuAcF2odxXHZZxoLVa3ebkK9Ho1LObAPgWy6yxBLOCt
oT2CZBtBskqWBD9KfJxxI+yO59i5e8f7nTt2twMCADs=}

set icon_dataquery2 {
R0lGODlhFAAUAIQAAMLCwoaGhm5ubjIyMlZWVj4+PgAAAHNKAFAyANHR0SQk
JJZiALl6AHp6eiYmJmJiYoRXALaDMxoaGmtFAP64SLZ5GtySAdySAJ1oALa2
tv///////////////////////yH5BAEKAB8ALAAAAAAUABQAAAW54CeKQCAM
6CAEwOiKRDEYB4IcxlAQ75cQisNiwSgyhgcFIeFqBInG6CLZaBocQmgR6TBU
Rw8DonA7mM1jhOHhCttwhni8pmaDxULI4CGDTOtteAsyEWESEzVrgTcLORQV
cQOJdiJuQnuPkZOLQgwWFDMFiIB3jJ4UDg9+m6WdFgIVF0eslYIMGAWxs6Qi
DbZhBrJ/XlamGAYFwolfIj8KphfKCEpMLhkxM3KROxk9zQ0PBOIEDw3VIyEA
Ow==}

set icon_datastore {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1P/isf/Ujv/Ga/+4SP+qJf+qANySALl6AJZiAHNKAFAyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSj4+PjIyMiYmJv//////////////////////////
/////////////////////yH5BAEAAP8ALAAAAAAUABQAAAjcAP8JHPgv3bp2
8hLKa7cuHcGH7+LJA0ChQgUKAOTFe/fw37l38yhMmCChpISRFOa9O0eQXUiS
JmNOSMmuJYCXMEuinAeg5kB3ACrEu0ihaFGhFQC4IwjUIkYAUKFWTLr0Z1CR
MXVWVMoUagWSERw8iHByq7t1aNcBNRRUQtixZalGjWqIbYW3ZGfKJVS3b92g
YvOaBZCocOG6iQDD1at0LlRDie8Gjqs0rVrCbfFSriqQnVewkxn77HwV9OKt
oz2CvAhWcAWVLAl+lOg448bYHc+xc/eu9zt37HAHBAA7}

set icon_delete {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1P/isf/Ujv/Ga/+4SP+qJf+qANySALl6AJZiAHNKAFAyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSv//////////////////////////////////////
/////////////////////yH5BAEAAP8ALAAAAAAUABQAAAiOAP8JHEiwoEGB
ABIe/AdPIcGEMRwSbBgRwECINSpOBBAjo0OONUJqZAgy5A2L/xLeCOnRnbuS
NU6iTAlgpUiMJiUirMkyRsecMx/yZAl04b+XNnO6M3oUZkujOImOLBj1RtKp
O3/GVNlTYlUALod6RAmAqEyBDZPWIMvz7MC0W2eq1Im2Jt2EQTfmZbowIAA7}

set icon_deletebook {
R0lGODlhFAAUAIQAAD4+PgAAAGJiYn9/f3MAJf9rj7kAPdwASQAAvwAAngAA
gQAAXpYAMQAAPwAAMAAAHP///7y8vP//////////////////////////////
/////////////////////////yH5BAEKAB8ALAAAAAAUABQAAAWqIBAEgGCK
pKkOXxsQBSkXxGiP7BcYRywWB0MAkSgqAoKWiBcDCgEJhfSYVO56QdJ0imxZ
gb6tdNH9Hhg97ZZc/Z0D6PC0UQ4AGbJ4YLqgV194IiIMNXx+VloBCSgAYw0O
ZS0Ce4piCn2QVZIBZGILnw0PkR+TdHx9DY+imqQBkJeoDg4PtKOToje5I6yT
ARARv8HAwAI5mwHDwsLFXh8Dvbq5xi3PKtbWxiEAOw==}

set icon_deleterow {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1P/isf/Ujv/Ga/+4SP+qJf+qANySALl6AJZiAHNKAFAyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSj4+PjIyMiYmJhoaGg4ODv/78KCgpICAgP8AAAD/
AP//AAAA//8A/wD//////yH5BAEAAP4ALAAAAAAUABQAAAjCANsBABDPn8F4
A90ZXMgQAI4YBP0hjIEDgLuLGN2d8wfARg2IE2vYGEiSJDyJHT8CiCGS4D92
/2L+A3DSH7yULEfGiwlTJs2FIUHK7Bnzp82VNW6o3PlS5syTIW8AUAqSkdWr
P5FKRUgVwCFG/wgROpQVx9ZDXCsmYjT2UKKfAgkecouQ4Nq2b2vCi+c20dq+
f/3mNXjzquHDVo3edEq0qU+9ABhLfkw48tDJRSFjdpy5csnPoGuey0i6tEaG
qFOnDggAOw==}

set icon_end {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1P/isf/Ujv/Ga/+4SP+qJf+qANySALl6AJZiAHNKAFAyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSj4+PjIyMiYmJhoaGg4ODv/78KCgpICAgP8AAAD/
AP//AAAA//8A/wD//////yH5BAEAAP4ALAAAAAAUABQAAAicAP0JHEiwoMGD
CBOeO1dwYUJ/59y5Yygw4kSEEQEAuJhxI8WBCzMS8ijSI0iJEgEUGjnRnUqW
FF1q1Gho5UwANWH6c/mPkE9DOQEoIgTUZksAg4AqDapIqVGXRJcaOqRIqFKq
G10eSsT10NSqihR5xXr05iGsM89W5YhS69qMZD+GdPk241uDHdlqvHjQolyJ
H/sGhjj4oeHDCAMCADs=}

set icon_eyeball {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1P/isf/Ujv/Ga/+4SP+qJf+qANySALl6AJZiAHNKAFAyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSj4+PjIyMiYmJhoaGg4ODv/78KCgpICAgP8AAAD/
AP//AAAA//8A/wD//////yH5BAEAAP4ALAAAAAAUABQAAAj+AP0JFHjuHLp1
7dqtQ1dwoEOC6+DJAyBvojx46849JPgOgLuF5swddAfgnUaH5zqqK1dOnAhx
4liqK3nSX0oA61rCfAHTZbl1NG0CXdmTEB48hHjGnJnxHLx35V6Kw5OIDZtE
eFyKM+cOnkF5616+wKPoXyVDhhRljblO3kEA6FwSSvTvHwAAlwwlIgQTHc52
8szBxMOm0t27htjgeSHCnLyEgV8SNnQYQOK1jhXCFfdirqFLd/Pu7YsTHVip
ZNGiVcvzp1un7nSOrXp1beOuBYdGhWkUac9yTDXezNmT82+gJgfeVCcYplRz
M5Oj7PgRXciRQTeei2jRIsaa2g0HIlTIELy/gAA7}

set icon_folderout {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1Pjisd/UjtHJa8O4SL2qJcWqAK+SAJN6AGJiAEpKADIyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSj4+Pv//////////////////////////////////
/////////////////////yH5BAEAAP8ALAAAAAAUABQAAAinAP8JHEiwoMGD
CAueW9euYcN15xL+W9gOgEWL7SBGPHiuYgMFIBUAcEjS4bmOABQ4WOkgwsWX
F9uhVMlyZcibLmVWVCBBQsgGQIMCzYlygkWhSIeO7BgPgCEAE6JGTUq0KaGn
MCcgzVnxqqGvYKFuHVkx0ddEaNGKFVoVgFmYa4MSbdc0EVSpWsfqhGoxgt+/
gP0urQi3cMyJJRMn3niysePHjSVKDggAOw==}

set icon_help {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1P/isf/Ujv/Ga/+4SP+qJf+qANySALl6AJZiAHNKAFAyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSj4+PjIyMiYmJhoaGg4ODv/78KCgpICAgP8AAAD/
AP//AAAA//8A/wD//////yH5BAEAAP4ALAAAAAAUABQAAAjGAP2dc0ewoMGD
7s4JdAegocOHEAEkZBjuQYOLGDNefBBOIkOLC0KKHCnygUcADRb8+5fN2zd3
8QZ4y0ZzQYOTKVlyi5mNIb1uNW8SRKkyWzcA8ow2nJnNJs6i2eS5UwqAqdOh
OWlqHQAgHtCmQhlm1ZptnruvYJ+SzdaOqdarYheQ7Rbv21q4RMkyBHA3bF6t
37r2PWlx7V2bJodWlBtSI0aOEv3tFdnAZMSGCf1JRlm5YTyEBBVq/ujZnebT
qFHvlSg6deqAADs=}

set icon_home {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1P/isf/Ujv/Ga/+4SP+qJf+qANySALl6AJZiAHNKAFAyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSv//////////////////////////////////////
/////////////////////yH5BAEAAP8ALAAAAAAUABQAAAjJAP8JHEiwoMF/
8BLCG+jO3UGGAHLkAPBvHTwAAOCte+gOQI0bGTFOmIBRo8GONSYCqPAgwsgK
JTdCxMjSpYQJNyXAzLix48qWOXEKvbmzIQAKDyhMUMp0qVOlAIzSrEC1qtWd
Uf8ZNce1q1euUR0K7FgOnVl05TCqTSt2LIBxat8CELdIkdy2WuVSlVsX0dys
EOFSoCBXkaVJf/F2hItTblxxgN0yjvB2nGXLkBUDILcSJrnPn8VlJugzrmm1
eLU2XM2a9cPXBgMCADs=}

set icon_inform {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1P/isf/Ujv/Ga/+4SP+qJf+qANySALl6AJZiAHNKAFAyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSj4+PjIyMiYmJhoaGg4ODv/78KCgpP//////////
/////////////////////yH5BAEAAP8ALAAAAAAUABQAAAjbAP8JFHjuHLp1
7dqtQ1dwoEOC6+DJAyBvojx46849JPgOgLuF5swddAfgnUaH5zqqK1dOnEtx
LNWVPPkvJYB1LcWNm3jPZbl1M2sCXfnyHICSL8vJzHgO3rucLsfBo3fupThz
7uAZlLfOqlerP+UdBIDO67p48dR5RXeznTxzXssdZefVnLyEb+POrXsXaFmw
e62yXchVLwC6SdeJbeoOKszALrFqPTcUqtzDSZdqtIlT3Dl29OjFq/ozKEcA
6uDWlWnyoc2P6EKONO06okWLGGluLHgw4cKGDgMCADs=}

set icon_magnify {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1Pjisd/UjtHJa8O4SL2qJcWqAK+SAJN6AGJiAEpKADIyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSj4+PjIyMiYmJhoaGg4ODv/78KCgpICAgP8AAAD/
AP//AAAA//8A/wD//////yH5BAEAAP4ALAAAAAAUABQAAAi/AP0JRMfOnUF3
7NAJXMhQoDp38ABIBADPnbqGDNVFbHeOHLlz7ShexIjOHYCOalKq+QjAncKG
7OC1I6fm35o1Kcm1g8cOo8lzNf99+YJTzbmWPgHQXDN0KE5ySBuaXNqU6Mqo
DH+mZGrVKNaFMWduLaozXs+GJU/SVMkSQDyM/jQC4OgRJEUKbuE+jDgxHoAJ
ESTkJVnwIDu/ERYIfgsXI2LFgxszfLxYckPKkS37ezwBgObJfysw/izQbzx1
AQEAOw==}

set icon_newdata {
R0lGODlhFAAUAIQAAP///7a2tp6enoaGhv/Ga/+4SP//ANzcAP+qJf+qANyS
ALl6AJZiAIAAAHp6em5ubmJiYlZWVnNKAFAyAD4+PjIyMiYmJgAAAP//////
/////////////////////////yH5BAEIAB8ALAAAAAAUABQAAAW54CeKyvBU
aPUMwuiShHJJ0yRdFRW9X6AQhthiuGAwJJZIwKVIHAyHhII4PFoco+bhANhK
q9YL9gM0GAAAs5kgoVEmF0jW+fTKLrNanOmEfolHcHIjED9BCgoFCFOBe4QX
CQYJC4mLRTSOIhCQkpSKjJiDmpyTlaCCLps/U6aXqI8TCgyelo2iH5s2s622
Lg4XurSnYr7AErufrsQjAREWwYiuSUsuzRQVeNk4OtQ8AQ4QEeIREA7dIiEA
Ow==}

set icon_save {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1P/isf/Ujv/Ga/+4SP+qJf+qANySALl6AJZiAHNKAFAyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSj4+PjIyMiYmJhoaGg4ODv/78KCgpICAgP8AAAD/
AP//AAAA//8A/wD//////yH5BAEAAP4ALAAAAAAUABQAAAi2ANvBg9euoMGD
BwcKHAigocOHDwdKZKcOocV26dhJBEDxIsKMABh29GgQpMiKJAueYxcSHkeU
Kc2xPJmyoMyWL2u2W4mTHUV1QNWhQ3euqLmVM136XMq0qc+e7N5JnSrVnVV3
T0W++/ePnNev5uK9c2dS6VZ37+L9K2euHDmxZJNyfEcOrdq25t6OLTu3btq1
bfXG7UnX7j+8gvnCozsUnbnHeeGaROcSomWI8PxRlsi5M+d2AQEAOw==}

set icon_undo {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1P/isf/Ujv/Ga/+4SP+qJf+qANySALl6AJZiAHNKAFAyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQCrPQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSj4+PjIyMiYmJhoaGg4ODv/78KCgpICAgP8AAAD/
AP//AAAA//8A/wD//////yH5BAEAAP4ALAAAAAAUABQAAAimAP0JHEiwoMGD
CBMqVHgOnrtzCwk2BADgYUR/E2NUPMexI8SCGV9UdEeSJLt06STCAxDjRQ2K
MGOeFJjxX40aNHLqrGHjBoCZK2PYvEm06E2f7M65A3AjhtGnRwGkU8pURQ0V
N7JqLWrjJ8alN1SoiEnxRtEQAGiCHesOJUoANoiiHUjVp7uB6eDKTUt3aUW8
em/OlUjyo7+8ZO8uTFeyZMqLkCMGBAA7}

set icon_usermagnify {
R0lGODlhFAAUAIQAAAQEBC8sBDo3Ok9LBE9LT2RfBGRfZG9pb3p0eo90BI+S
j5qcmq+SBK+mr7qmJLqxusS7T9rZj9rZ2voE+vrjuvru2vru+v//////////
/////////////////////////yH5BAEAAB8ALAAAAAAUABQAAAW94Cc2iGEa
SCOurKgYBCADhKG0rBIfVRQlB9oN1zAAChVLBOIoCAAGVQtBOCR8S0cCcCAg
cEZBYclkOB9QMBSQcDgYW4Ml3TIujIVEAbqYG9QzT08zdCxUBxaJFhKMEgcC
Xy1FAA2JjQ0SMgJgOlyNjjQDAJssRi8xgUdwo6UAEiQnKE8MFFukH0YycAGr
owC0tiIPJr8JvHEGs7WsIkarq38fysG4xdbR0r8Ue81HewV72NkFAaS5hIUi
ggohADs=}

set icon_users {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1Pjisd/UjtHJa8O4SL2qJcWqAK+SAJN6AGJiAEpKADIyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYlZWVkpKSj4+PjIyMiYmJhoaGg4ODv/78KCgpICAgP8AAAD/
AP//AAAA//8A/wD//////yH5BAEAAP4ALAAAAAAUABQAAAjnAP0J9IfOXTwA
8dwZROgO3cCH6A5OkDABIQWKCB0+POcOQAQFDBhIADAh5Eh35zbGm6DgHwMH
Dya4CxkzXsqB5wBICPnygYR4DBr4BHBT4LmVL2FGkKl0gs2H/jpKePAgwsgJ
VU9C9Zeu48SKAC5WdJfuYUcAaA8eRIuQLQB3AjuKmzuXnF1yANDdfRsXADl0
de3qzfsXL9yoft+Ju0vuHV69jvkiJlehsuUKeC0b7kvZqoTPmHVKCH34rMfR
VtmmRnuYY0erFVJTTK2wKOLUuE9LNqs7N+2tXitOEE5yLHC3yNke9hcQADs=}

set icon_open {
R0lGODlhFAAUAOcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwMDcwKbK8P/w
1Pjisd/UjtHJa8O4SL2qJcWqAK+SAJN6AGJiAEpKADIyAP/j1P/Hsf+rjv+P
a/9zSP9XJf9VANxJALk9AJYxAHMlAFAZAP/U1P+xsf+Ojv9ra/9ISP8lJf4A
ANwAALkAAJYAAHMAAFAAAP/U4/+xx/+Oq/9rj/9Ic/8lV/8AVdwASbkAPZYA
MXMAJVAAGf/U8P+x4v+O1P9rxv9IuP8lqv8AqtwAkrkAepYAYnMASlAAMv/U
//+x//+O//9r//9I//8l//4A/twA3LkAuZYAlnMAc1AAUPDU/+Kx/9SO/8Zr
/7hI/6ol/6oA/5IA3HoAuWIAlkoAczIAUOPU/8ex/6uO/49r/3NI/1cl/1UA
/0kA3D0AuTEAliUAcxkAUNTU/7Gx/46O/2tr/0hI/yUl/wAA/gAA3AAAuQAA
lgAAcwAAUNTj/7HH/46r/2uP/0hz/yVX/wBV/wBJ3AA9uQAxlgAlcwAZUNTw
/7Hi/47U/2vG/0i4/yWq/wCq/wCS3AB6uQBilgBKcwAyUNT//7H//47//2v/
/0j//yX//wD+/gDc3AC5uQCWlgBzcwBQUNT/8LH/4o7/1Gv/xkj/uCX/qgD/
qgDckgC5egCWYgBzSgBQMtT/47H/x47/q2v/j0j/cyX/VwD/VQDcSQC5PQCW
MQBzJQBQGdT/1LH/sY7/jmv/a0j/SCX/JQD+AADcAAC5AACWAABzAABQAOP/
1Mf/sav/jo//a3P/SFf/JVX/AEncAD25ADGWACVzABlQAPD/1OL/sdT/jsb/
a7j/SKr/Jar/AJLcAHq5AGKWAEpzADJQAP//1P//sf//jv//a///SP//Jf7+
ANzcALm5AJaWAHNzAFBQAPLy8ubm5tra2s7OzsLCwra2tqqqqp6enpKSkoaG
hnp6em5ubmJiYv//////////////////////////////////////////////
/////////////////////yH5BAEAAP8ALAAAAAAUABQAAAinAP8JHEiwoMGD
CAueW9euYcN15xL+W9gOgEWL7iBGPHiuYgMFIBUAcOewZMNzHQEoaMCyQYSL
MC+2S6nAgYOWDHLqzPlyZsWaNlsKbdlT3U+bDiQoXbrUQc+KAJiGnKpAglMA
P6ci3WpTQgQJWAE84ErW5lewFa2WJasUa8Wxa7e2bacuatytX7GmjMC3r1+/
E/TWjUk4ZruJJhMn3oiysePHjSVKDggAOw==}

set icon_gnu {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}


# exit-Prozedure umlenken...
rename exit mein_exit 
proc exit {} {
	tk_messageBox 	-icon info\
			-message "Nicht vergessen, dass man den iPod nicht\
				 einfach aus dem USB-Port entfernt werden darf!\
				 Das Geraet muss aus dem Verzeichnisbaum ausgehangen\
				 werden (umount)."\
			-title "Info..."\
			-type ok
	mein_exit
}

# Hilfeblasen erzeugen...
proc balloon {w help} {
	bind $w <Enter> "after 500 [list balloon:show %W [list $help]]"
	bind $w <Leave> "destroy %W.balloon"
}

proc balloon:show {w arg} {
	global balloon_sichtbar
	if {$balloon_sichtbar} {
	if {[eval winfo containing  [winfo pointerxy .]]!=$w} {return}
	set top $w.balloon
	catch {destroy $top}
	toplevel $top -bd 1 -bg black
	wm overrideredirect $top 1
	pack [message $top.txt 	-aspect 10000 -bg yellow \
				-font fixed -text $arg]
	set wmx [winfo rootx $w]
	set wmy [expr [winfo rooty $w]+[winfo height $w]]
	wm geometry $top [winfo reqwidth $top.txt]x[winfo reqheight $top.txt]+$wmx+$wmy
	raise $top
	}
}

# Verzeichnis waehlen
proc choose_dir {init_dir title} {
set z_dir [tk_chooseDirectory -initialdir $init_dir -title $title]
if {$z_dir != ""} {
	return $z_dir
} else {
	return $init_dir
}
}


# Menueleiste...
set mbar [frame .mbar -borderwidth 1 -relief raised]
pack $mbar -fill x
set m_file [menubutton $mbar.file -text "Datei" -underline 0 -menu $mbar.file.m]
pack $m_file -side left
menu $m_file.m
$m_file.m add command -label "Anfangsverzeichnis" -underline 0 -command {list_dir $home_dir}\
		      -image [image create photo -data $icon_home] -compound left
$m_file.m add command -label "Uebergeordnetes Verzeichnis" -underline 0 -command {list_dir $parent_dir}\
		      -image [image create photo -data $icon_folderout] -compound left
$m_file.m add command -label "markierte Dateien auf iPod kopieren" -underline 0\
		      -command {copy_sel_to_ipod $quelle $ipod_dir}\
		      -image [image create photo -data $icon_end] -compound left
$m_file.m add separator		      
$m_file.m add command -label "Beenden" -underline 0 -command exit\
		      -image [image create photo -data $icon_delete] -compound left
set m_ipod [menubutton $mbar.iPod -text "iPod" -underline 0 -menu $mbar.iPod.m]
pack $m_ipod -side left
menu $m_ipod.m
$m_ipod.m add command -label "markierte Titel auf iPod loeschen" -underline 0 -command {ipod_del_sel $ipod $ipod_dir 1}\
		      -image [image create photo -data $icon_deleterow] -compound left
$m_ipod.m add command -label "alle Titel auf iPod loeschen" -underline 0 -command {ipod_del_all $ipod $ipod_dir}\
		      -image [image create photo -data $icon_deletebook] -compound left
$m_ipod.m add separator		      
$m_ipod.m add command -label "iPod neu einlesen" -underline 0 -command {list_ipod $ipod_dir}\
		      -image [image create photo -data $icon_magnify] -compound left
$m_ipod.m add separator		      
$m_ipod.m add command -label "iTunes-DB erzeugen (mktunes)" -underline 0 -command {mktunes $ipod_dir}\
		      -image [image create photo -data $icon_dataextract] -compound left
$m_ipod.m add command -label "iTunes-DB importieren (tunes2pod)" -underline 0 -command {tunes2pod $ipod_dir}\
		      -image [image create photo -data $icon_datastore] -compound left
set m_hilfe [menubutton $mbar.hilfe -text "Hilfe" -underline 0 -menu $mbar.hilfe.m]
pack $m_hilfe -side right
menu $m_hilfe.m
$m_hilfe.m add command -label "Hilfe" -underline 0 -command prog_hilfe\
		      -image [image create photo -data $icon_help] -compound left
$m_hilfe.m add command -label "Info" -underline 0 -command prog_info\
		      -image [image create photo -data $icon_inform] -compound left

set help [label .help -relief solid -borderwidth 0 -anchor w]
pack $help -side bottom -fill x

set notebook [NoteBook .nb]
pack $notebook -expand true -fill both

##### Haupt-Notebook ######
set frame [$notebook insert end sp -text "iPod befuellen" ]
set panedWindow [PanedWindow $frame.pw -side top ]
pack $frame.pw -expand true -fill both

# linke Seite -> Quelle (Filesystem)
set pane  [$panedWindow add  -weight 1]
set quelle_button_frame [frame $pane.quelle_button_frame]
set b_homedir [button $quelle_button_frame.b_homedir -image [image create photo -data $icon_home]\
 -command {list_dir $home_dir}]
pack $b_homedir -side left
set b_parentdir [button $quelle_button_frame.b_parentdir -image [image create photo -data $icon_folderout]\
							 -command {list_dir $parent_dir}]
pack $b_parentdir -side left
set b_sel_copy	[button $quelle_button_frame.b_sel_copy	-image [image create photo -data $icon_end]\
							-command {copy_sel_to_ipod $quelle $ipod_dir}]
pack $b_sel_copy -side right
pack $quelle_button_frame -fill x
set sw_left    [ScrolledWindow $pane.sw_left]
set quelle [listbox   $sw_left.quelle -width 40 -height 15 -selectmode multiple]
$sw_left setwidget $quelle
pack $sw_left -fill both -expand yes
set dirsize [label $pane.dirsize -relief solid -borderwidth 0 -anchor e -text ""]
pack $dirsize -side bottom -fill x

# ... Bindings ...
bind $quelle      <Double-Button-1> {list_dir [$quelle get active]}
bind $quelle      <KeyPress-Return> {list_dir [selection get]}
bind $quelle      <<ListboxSelect>> {select_size $quelle $dirsize}

# ... Hilfeblase ...
balloon $b_homedir "In Anfangsverzeichnis\n$home_dir wechseln..."
balloon $b_parentdir "In uebergeordnetes Verzeichnis\n$parent_dir wechseln..."
balloon $b_sel_copy "Inhalt der selektierten\nVerzeichnisse auf iPod kopieren..."
balloon $dirsize "Groesse der selektierten Dateien..."
balloon $quelle "Verzeichnisse unter\n$akt_dir"

# rechte Seite -> iPod
set pane  [$panedWindow add -weight 9]
set ipod_button_frame [frame $pane.ipod_button_frame]
set b_ipod_titel [button $ipod_button_frame.b_ipod_titel -image [image create photo -data $icon_magnify]\
							 -command {rb_ipod_sicht 1 0 0}]
pack $b_ipod_titel -side left
set b_ipod_album [button $ipod_button_frame.b_ipod_album -image [image create photo -data $icon_cd]\
							 -command {rb_ipod_sicht 0 1 0}]
pack $b_ipod_album -side left
set b_ipod_interpret [button $ipod_button_frame.b_ipod_interpret -image [image create photo -data $icon_users]\
								 -command {rb_ipod_sicht 0 0 1}]
pack $b_ipod_interpret -side left
set l_ipod_liste [label $ipod_button_frame.l_ipod_liste -fg darkblue]
pack $l_ipod_liste -side left -padx 10 
set b_all_del	[button $ipod_button_frame.b_all_del 	-image [image create photo -data $icon_deletebook]\
							-command {ipod_del_all $ipod $ipod_dir}]
pack $b_all_del -side right
set b_sel_del	[button $ipod_button_frame.b_sel_del	-image [image create photo -data $icon_deleterow]\
							-command {ipod_del_sel $ipod $ipod_dir 1}]
pack $b_sel_del -side right
pack $ipod_button_frame -fill x
set sw_right    [ScrolledWindow $pane.sw_right]
set ipod [listbox   $sw_right.ipod -width 40 -height 15 -selectmode multiple]
$sw_right setwidget $ipod
pack $sw_right -fill both -expand yes
set ipodsize [label $pane.ipodsize -relief solid -borderwidth 0 -anchor e -text ""]
pack $ipodsize -side bottom -fill x

# ... Hilfeblasen ...
balloon $b_sel_del "selektierte Titel\nvom iPod loeschen"
balloon $b_all_del "alle Titel vom\niPod loeschen"
#balloon $b_list_ipod "iPod neu einlesen"
balloon $b_ipod_titel "iPod-Inhalt - Titel auflisten"
balloon $b_ipod_album "iPod-Inhalt - Alben auflisten"
balloon $b_ipod_interpret "iPod-Inhalt - Interpreten auflisten"
balloon $ipod "iPod-Inhalt\n($ipod_dir)"
balloon $ipodsize "Belegung iPod"

##### Notebook fuer Konfiguration #####
set frame [$notebook insert end tf -text "Konfiguration"]
set tframe [TitleFrame $frame.konfig -text "Parameter"]
pack $tframe  -expand true -fill both
set kframe [$tframe getframe]

set l_home_dir [label $kframe.l_home_dir -text "Anfangsverzeichnis:"]
grid $l_home_dir -row 0 -column 0 -sticky e
set e_home_dir [entry $kframe.e_home_dir -textvariable home_dir -bg white -width 50]
grid $e_home_dir -row 0 -column 1 -sticky ew
set b_home_dir [button $kframe.b_home_dir -image [image create photo -data $icon_open]\
					  -command {set home_dir [choose_dir $home_dir "Anfangsverz. waehlen:"]}]
grid $b_home_dir -row 0 -column 2 -sticky ew
set l_ipod_dir [label $kframe.l_ipod_dir -text "iPod-Verzeichnis:"]
grid $l_ipod_dir -row 1 -column 0 -sticky e
set e_ipod_dir [entry $kframe.b_ipod_dir -textvariable ipod_dir -bg white -width 50]
grid $e_ipod_dir -row 1 -column 1 -sticky ew
set bu_ipod_dir [button $kframe.bu_ipod_dir -image [image create photo -data $icon_open]\
						 -command {set ipod_dir [choose_dir $ipod_dir "iPod-Verz. waehlen:"]}]
grid $bu_ipod_dir -row 1 -column 2 -sticky ew
set l_chk_balloon [label $kframe.l_chk_balloon -text "Blasenhilfe an/aus:"]
grid $l_chk_balloon -row 3 -column 0 -sticky e
set chk_balloon [checkbutton $kframe.chk_ballon -variable balloon_sichtbar]
grid $chk_balloon -row 3 -column 1 -sticky w

set b_save_conf [button $tframe.b_save_conf -image [image create photo -data $icon_save]\
					 -command config_save]
pack $b_save_conf -side left -anchor s
set b_read_conf [button $tframe.b_read_conf -image [image create photo -data $icon_undo]\
						 -command config_read]
pack $b_read_conf -side left -anchor s

# ... Hilfeblasen ...
balloon $b_save_conf "Konfiguration abspeichern..."
balloon $b_read_conf "Konfiguration neu einlesen..."
balloon $e_ipod_dir "iPod-Verzeichnis"
balloon $e_home_dir "Anfangsverzeichnis"
balloon $bu_ipod_dir "iPod-Verzeichnis waehlen..."
balloon $b_home_dir "Anfangsverzeichnis waehlen..."
balloon $chk_balloon "Blasenhilfe an/aus"

$notebook raise [$notebook page 0]
 
wm title .  "tk_gnupod"
wm geometry . 800x600
wm protocol . WM_DELETE_WINDOW {exit}
#wm iconbitmap . [image create photo -data $icon_eyeball]


# *** ########## rb_ipod_sicht ###########
# ***
# *** Steuerung Umschalten zwischen Titel-, Album-, Interpret-Sicht... 
# ***
proc rb_ipod_sicht {t a i} {
	global b_ipod_titel b_ipod_album b_ipod_interpret titel album interpret ipod_dir l_ipod_liste
	if {$t} {
		$b_ipod_titel configure -relief sunken
		$b_ipod_album configure -relief raised
		$b_ipod_interpret configure -relief raised
		$l_ipod_liste configure -text "Titel"
		set titel 1
		set album 0
		set interpret 0
	}
	if {$a} {
		$b_ipod_titel configure -relief raised
		$b_ipod_album configure -relief sunken
		$b_ipod_interpret configure -relief raised
		$l_ipod_liste configure -text "Alben"
		set titel 0
		set album 1
		set interpret 0
	}
	if {$i} {
		$b_ipod_titel configure -relief raised
		$b_ipod_album configure -relief raised
		$b_ipod_interpret configure -relief sunken
		$l_ipod_liste configure -text "Interpreten"
		set titel 0
		set album 0
		set interpret 1
	}
	list_ipod $ipod_dir
}

# *** ########## list_dir ###########
# ***
# *** Listet alles unter angebenen Verzeichnis in Listbox quelle
# ***
proc list_dir {dir} {
	global quelle b_parentdir dirsize l_dir_liste
	global akt_dir parent_dir
	if {[file isdirectory $dir]} { 
		set akt_dir $dir
		set parent_dir [file dirname $dir]
		balloon $quelle "Verzeichnisse unter\n$akt_dir"
		balloon $b_parentdir "In uebergeordnetes Verzeichnis\n$parent_dir wechseln..."
        	# Listbox leeren...
		$quelle delete 0 end 
		# zuerst alle Verzeichnisse...
		foreach i [lsort [glob -directory $dir -types {d} -nocomplain *]] {
			$quelle insert end  $i
		}
		# ... und dann die Dateien ...
		foreach i [lsort [glob -directory $dir -types {f} -nocomplain *]] {
			$quelle insert end [file tail $i]
		}
		select_size $quelle $dirsize
	}
}

# *** ########## get_dirsize ###########
# ***
# *** Berechnet die Gesamtgroesse aller Files ab angegenen Verz.
# ***
proc get_dirsize {dir} {
	set size 0.0
	foreach i [glob -directory $dir -types {d f} -nocomplain *] {
		if {[file isfile $i]} {
			set size [expr $size + [file size $i]]
		} else {
			set size [expr $size + [get_dirsize $i]]
                }
	}
	return $size
}

# *** ########## select_size ###########
# ***
# *** Berechnet Gesamtgroesse aller Files der in quelle selekt. Verz./Dateien
# ***
proc select_size {quelle output} {
	global akt_dir sel_dirsize b_sel_copy
	set size 0.0
	set sel [$quelle curselection]
	foreach i $sel {
		set s [$quelle get $i]
		if {[file isdir $s]} {
			set size [expr $size + [get_dirsize $s]]
		} else {
			set size [expr $size + [file size "$akt_dir/$s"]]		
		}
	}
	set size [expr $size/1024]
	$output configure -text [format "%10.0f kByte selektiert" $size]
	set sel_dirsize $size
}

# *** ########## eintrag_nicht_vorhanden ###########
# ***
# *** Gibt 1 zurueck, wenn eintrag nicht in ipod-Liste
# ***
proc eintrag_nicht_vorhanden {ipod eintrag} {
	set liste [$ipod get 0 end]
	set nicht_vorhanden 1
	foreach i $liste {
		if {$i == $eintrag} {set nicht_vorhanden 0}
	}
	return $nicht_vorhanden
}

# *** ########## list_ipod ###########
# ***
# *** Listet Inhalt des iPod in Listbox ipod; berechnet belegten Platz (via gnupod_search)
# ***
proc list_ipod {ipod_dir} {
	global ipodsize ipod ipod_freesize titel album interpret
	$ipod delete 0 end
	if {[catch {set output [exec gnupod_search -m $ipod_dir -o "*" 2> /dev/null]}]} {
		tk_messageBox 	-icon error\
				-message "Das Verzeichnis $ipod_dir scheint\
					 kein iPod zu sein. Bitte die Konfiguration\
					 von tk_gnupod ueberpruefen oder den\
					 iPod entsprechend in den Verzeichnisbaum einbinden\
					 (mounten)!"\
				-title "Info..."\
				-type ok
	} else {
	# ... die ersten 3 Zeilen braucht man nicht...
	set output [lrange [split $output \x0a] 3 end]
	if {$titel} {
		foreach i $output {
			set z [split $i |]
			set k ""
			foreach j $z {
				set $j [string trimright $j]
				set k "$k $j"
			}
			$ipod insert end $k
		}
	}
	if {$album} {
		foreach i $output {
			set z [split $i |]
			set str_z  "[lindex $z 1]->[lindex $z 2]"
			if {[eintrag_nicht_vorhanden $ipod $str_z]} {
				$ipod insert end $str_z
			}
		}	
	}
	if {$interpret} {
		foreach i $output {
			set z [split $i |]
			set str_z [lindex $z 1]
			if {[eintrag_nicht_vorhanden $ipod $str_z]} {
				$ipod insert end $str_z
			}
		}		
	}
	
	# den Platz auf dem iPod bestimmen (via df)
	set df_out [exec df $ipod_dir]
	set df_out [lrange [split $df_out \x0a] 1 end]
	set df_out [lindex $df_out 0]
	set ipod_freesize [lindex $df_out 3]
	$ipodsize configure -text [format "%d kB von max. %d kB noch frei. (%s belegt)"\
				$ipod_freesize [lindex $df_out 1] [lindex $df_out 4]]
	}
}

# *** ########## copy_dir_to_ipod ###########
# ***
# *** Kopiert angegebenes Verz. auf iPod (via gnupod_addsong) 
# ***
proc copy_dir_to_ipod {dir ipod_dir} {
	global help
	foreach i [glob -directory $dir -types {d f} -nocomplain *] {
		if {[file isfile $i]} {
			$help configure -text "Kopiere $i ..." -bg yellow
			update
			set output [exec gnupod_addsong -m $ipod_dir $i 2> /dev/null]
		} else {
			copy_dir_to_ipod $i $ipod_dir
                }
	}
	$help configure -bg #d9d9d9
}

# *** ########## copy_sel_to_ipod ###########
# ***
# *** Kopiert selektierte Verz./Dateien auf iPod (via gnupod_addsong)
# ***
proc copy_sel_to_ipod {quelle ipod_dir} {
	global akt_dir help ipod_freesize sel_dirsize dirsize
	if {$sel_dirsize < $ipod_freesize} {
		set sel [$quelle curselection]
		foreach i $sel {
			set s [$quelle get $i]
			if {[file isfile "$akt_dir/$s"]} {
				$help configure -text "Kopiere $akt_dir/$s ..." -bg yellow
				update
				set output [exec gnupod_addsong -m $ipod_dir "$akt_dir/$s" 2> /dev/null]
			} else {
				copy_dir_to_ipod $s $ipod_dir
        	        }
		}
		mktunes $ipod_dir
		list_ipod $ipod_dir
		$quelle selection clear 0 end
		$dirsize configure -text [format "%20.0f kB selektiert" 0]		
		$help configure -text "" -bg #d9d9d9
	} else {
		tk_messageBox 	-icon error\
				-message "Die selektierten\
					 [format "%10.0f kByte" $sel_dirsize]\
					 sind zuviel fuer den iPod! Es passen maximal noch\
					 [format "%10.0f kByte" $ipod_freesize]\
					 drauf..."\
				-title "Info..."\
				-type ok
	}
}

# *** ########## ipod_del_all ###########
# ***
# *** Loescht gesamten Inhalt auf iPod (ruft ipod_del_sel auf...)
# ***
proc ipod_del_all {ipod ipod_dir} {
	set q [tk_dialog .d	{Frage...}\
				{Wirklich alle Titel auf dem iPod loeschen?}\
				question 1 {Ja} {Nein}]
	if {$q == 0} {
		$ipod selection set 0 end
		ipod_del_sel $ipod $ipod_dir 0
	}
}

# *** ########## ipod_del_sel ###########
# ***
# *** Loescht selectierten Titel vom iPod (via gnupod_search --delete)
# ***
proc ipod_del_sel {ipod ipod_dir dlg} {
	global help titel album interpret
	set q 0
	if {$dlg} {
		set q [tk_dialog .d	{Frage...}\
					{Selektierte Titel auf dem iPod loeschen?}\
					question 1 {Ja} {Nein}]
	}
	if {$q == 0} {
		if {$titel} {
			set sel [$ipod curselection]
			foreach i $sel {
				# ... warum index 1 -> komische Zeichen im String...
				set j [lindex [split [$ipod get $i] " "] 1]
				$help configure -text "Loesche [$ipod get $i] ..." -bg yellow
				update
				set output [exec gnupod_search -m $ipod_dir -i "$j" --delete 2> /dev/null]
			}
		}
		if {$album} {
			set sel [$ipod curselection]
			foreach i $sel {
				set j [string trim [lindex [split [$ipod get $i] "->"] 2]]
				$help configure -text "Loesche [$ipod get $i] ..." -bg yellow
				update
				set output [exec gnupod_search -m $ipod_dir -l "$j" --delete 2> /dev/null]
			}
		}
		if {$interpret} {
			set sel [$ipod curselection]
			foreach i $sel {
				set j [lindex [split [$ipod get $i] " "] 0]
				$help configure -text "Loesche [$ipod get $i] ..." -bg yellow
				update
				set output [exec gnupod_search -m $ipod_dir -a "$j" --delete 2> /dev/null]
			}
		}
	}
	mktunes $ipod_dir
	list_ipod $ipod_dir
	$help configure -text "" -bg #d9d9d9
}

# *** ########## mktunes ###########
# ***
# *** Generiert iTunesDB des iPod (via mktunes von gnupod)
# ***
proc mktunes {ipod_dir} {
	set output [exec mktunes -m $ipod_dir 2> /dev/null]
}

# *** ########## tunes2pod ###########
# ***
# *** Generiert aus iTunesDB Titeldaten fuer gnupod (via tunes2pod von gnupod)
# ***
proc tunes2pod {ipod_dir} {
	set output [exec tunes2pod -m $ipod_dir 2> /dev/null]
	list_ipod $ipod_dir
}

# *** ########## recover_ipod ###########
# ***
# *** baut die gnupodDB wieder neu auf (via gnupod_addsong --restore)
# ***
proc recover_ipod {ipod_dir} {
	set q [tk_dialog .d	{Frage...}\
				{Es wird versucht die gnupod-Titeldatenbank nach dem Inhalt\
				des iPod neu aufzubauen. Wirklich durchfuehren?}\
				question 1 {Ja} {Nein}]
	if {$q == 0} {
		set output [exec gnupod_addsong --restore -m $ipod_dir 2> /dev/null]
	}
	list_ipod $ipod_dir
}

# *** ########## gnupod_init ###########
# ***
# *** Initialisiert iPod fuer gnupod (via gnupod_INIT)
# ***
proc gnupod_init {ipod_dir} {
	set q [tk_dialog .d	{Frage...}\
				{Wirklich eine Initialisierung des iPod fuer gnupod durchfuehren?}\
				question 1 {Ja} {Nein}]
	if {$q == 0} {
		set output [exec gnupod_INIT -m $ipod_dir 2> /dev/null]
	}
	list_ipod $ipod_dir
}

# *** ########## config_save ###########
# ***
# *** Speichert die Konfiguration ab
# ***
proc config_save {} {
	global config_file home_dir ipod_dir balloon_sichtbar
	set fid [open $config_file w]
	puts $fid "set home_dir $home_dir"	
	puts $fid "set ipod_dir $ipod_dir"	
	puts $fid "set balloon_sichtbar $balloon_sichtbar"	
	close $fid
}

# *** ########## config_read ###########
# ***
# *** Einlesen der Konfiguration (bzw. Defaults setzen)
# ***
proc config_read {} {
	global config_file home_dir ipod_dir ipod_maxfill balloon_sichtbar
	if {[file exists $config_file]} {
		source $config_file
	} else {
		tk_messageBox 	-icon info\
			-message "Es ist keine Konfigurationsdatei vorhanden! Es werden \
			          die Defaultwerte geladen und dann als Konfiguration \
			          abgespeichert."\
			-title "Konfiguration..."\
			-type ok
		config_save	
	}
}

# *** ########## prog_info ###########
# ***
# *** zeigt Programm-Info-Fenster...
# ***
proc prog_info {} {
	global icon_gnu
	set notice [toplevel .notice]
	set finfo [frame $notice.info]
	pack $finfo -expand yes -fill both -pady 2 -pady 2
	set icon [label $finfo.icon -image [image create photo -data $icon_gnu]]
	pack $icon -side left -padx 8 -pady 8
	set titel [label $finfo.titel -text "tk_gnupod"]
	pack $titel -padx 8 -pady 8
	set version [label $finfo.version -text "Version 0.1"]
	pack $version -padx 8 -pady 8
	set autor [label $finfo.autor -text "Uwe Berger; 2006"]
	pack $autor -padx 8 -pady 8
	set ok [button $finfo.ok -text "OK" -command {destroy .notice}]
	pack $ok -pady 4
	wm title .notice "Info..."
	# ... Groesse festschreiben...
	update
	wm minsize .notice [winfo width .notice] [winfo height .notice]
	wm maxsize .notice [winfo width .notice] [winfo height .notice]
	center_window . .notice
}

# *** ########## center_window ###########
# ***
# *** w in tw zentrieren...
# ***
proc center_window {tw w} {
	set width [winfo width $w]
	set height [winfo height $w]
	set x [expr {[expr {([winfo width  $tw] - $width) / 2}] + [winfo x $tw]}]
	set y [expr {[expr {([winfo height $tw] - $height) / 2}] + [winfo y $tw]}]
	wm geometry $w ${width}x${height}+${x}+${y}
}

# *** ########## prog_hilfe ###########
# ***
# *** zeigt Programm-Hilfe-Fenster...
# ***
proc prog_hilfe {} {
	global readme_file 
	# der Hiletext befindet sich im Script-Quelltext selbst, zwischen den 
	# Schluesselwoertern *helpbegin* und *helpend* ...
	set helpbegin "*helpbegin*"
	set helpend "*helpend*"
	toplevel .hilfe
	frame .hilfe.f
	pack .hilfe.f -side top -fill y
	set hilfe_text [text .hilfe.f.hilfe_text -relief groove -bd 2\
						-wrap word\
						-yscrollcommand ".hilfe.f.scroll set"]
	scrollbar .hilfe.f.scroll -command "$hilfe_text yview"
	pack .hilfe.f.scroll -side right -fill y
	pack $hilfe_text -side top -anchor n
	# Scriptquelltext einlesen
	set fid [open $readme_file]
	set txt [read $fid]
	close $fid
	# alles zwischen Beginn und Ende ausschneiden 
	set txt [string range 	$txt\
				[expr [string first $helpbegin $txt] + [string length $helpbegin]]\
				[expr [string first $helpend $txt] - 1]]
	# Kommentarzeichen entfernen
	regsub -all {#} $txt "" txt
	$hilfe_text insert end $txt
	set ok [button .hilfe.ok -text "OK" -command {destroy .hilfe}]
	pack $ok -pady 4 -anchor s
	wm title .hilfe "Hilfe"
	$hilfe_text configure -state disabled
	update
	wm minsize .hilfe [winfo width .hilfe] [winfo height .hilfe]
	wm maxsize .hilfe [winfo width .hilfe] [winfo height .hilfe]
	center_window . .hilfe
}

update

config_read
list_dir  $akt_dir
rb_ipod_sicht 1 0 0
