#!/usr/bin/wish
# 
#                         tk_proctree
#                         ===========
#                      Uwe Berger; 2006
#

package require BWidget

option add *TitleFrame.l.font {helvetica 11 bold italic}
option add *Dialog.msg.font {helvetica 12 bold}

variable count
variable dblclick
variable node

set ascii 1

set pw    [PanedWindow .pw -side top]
set pane  [$pw add -weight 1]
set title [TitleFrame $pane.lf -text "/proc"]
set sw    [ScrolledWindow [$title getframe].sw \
                  -relief sunken -borderwidth 2]
set tree  [Tree $sw.tree \
                   -relief flat -borderwidth 0 -width 15 -highlightthickness 0\
		   -redraw 0 -dropenabled 1 -dragenabled 1 \
                   -dragevent 3 \
                   -droptypes {
                       TREE_NODE    {copy {} move {} link {}}
                       LISTBOX_ITEM {copy {} move {} link {}}
                   } \
                   -opencmd   "tree_moddir 1 $sw.tree" \
                   -closecmd  "tree_moddir 0 $sw.tree"]
$sw setwidget $tree

pack $sw    -side top  -expand yes -fill both
pack $title -fill both -expand yes

set pane [$pw add -weight 2]
set lf   [TitleFrame $pane.lf -text "Content"]

set sw   [ScrolledWindow [$lf getframe].sw \
                  -scrollbar both -auto none -relief sunken -borderwidth 2]
set content [text $sw.lb -wrap none]
$sw setwidget $content

pack $sw $lf -fill both -expand yes
pack $pw -fill both -expand yes

set b_ende [button .b_ende -command exit -text Ende]
pack $b_ende -side right


set r_ascii [radiobutton $lf.r_ascii -value 1 -text ASCII -variable ascii -command radio_event]
set r_hex [radiobutton $lf.r_hex -value 0 -text HEX -variable ascii -command radio_event]
pack $r_ascii -side left
pack $r_hex -side left

set e_input [entry $lf.e_input -width 50 -textvariable proc_input]
set b_input [button $lf.b_input -text "Schreiben..." -command {proc_write}]

pack $e_input -side right 
pack $b_input -side right


$tree bindText  <ButtonPress-1>        "tree_select 1 $tree"
$tree bindText  <Double-ButtonPress-1> "tree_select 2 $tree"
$tree bindImage <Double-ButtonPress-1> "tree_select 2 $tree"


wm title . "tk_proctree"
wm geometry . 800x600
wm protocol . WM_DELETE_WINDOW {exit}


proc radio_event {} {
	global tree
	set node [$tree selection get]
	$tree selection set $node
	tree_select 1 $tree $node
}

proc proc_write {} {
	global proc_input tree
	set node [$tree selection get]
	$tree selection set $node
        set dir [$tree itemcget $node -data]

	if {[catch {set fid [open $dir w]}]==1} {
		tk_messageBox 	-icon error\
				-message "Wahrscheinlich unzureichende Rechte zum Schreiben nach $dir!"\
				-title "Fehler"\
				-type ok
	} else {
		close $fid
	}
	set proc_input ""
}


proc tree_init { tree args } {
    variable count
    set count 0
    set rootdir [glob "/proc"]
    $tree insert end root home -text $rootdir -data $rootdir -open 1 -image [Bitmap::get openfold]
    tree_getdir $tree home $rootdir
    tree_select 1 $tree home
    $tree configure -redraw 1
}


proc tree_getdir { tree node path } {
    variable count

    set lentries [glob -nocomplain [file join $path "*"]]
    set lfiles   {}
    foreach f $lentries {
        set tail [file tail $f]
        if { [file isdirectory $f] } {
            $tree insert end $node n:$count \
                -text      $tail \
                -image     [Bitmap::get folder] \
                -drawcross allways \
                -data      $f
            incr count
        } else {
            $tree insert end $node n:$count \
                -text      $tail \
                -image     [Bitmap::get file] \
                -drawcross never \
                -data      $f
            incr count
        }
    }
    $tree itemconfigure $node -drawcross auto -data $lfiles
}


proc tree_moddir { idx tree node } {
    if { $idx && [$tree itemcget $node -drawcross] == "allways" } {
        tree_getdir $tree $node [$tree itemcget $node -data]
        if { [llength [$tree nodes $node]] } {
            $tree itemconfigure $node -image [Bitmap::get openfold]
        } else {
            $tree itemconfigure $node -image [Bitmap::get folder]
        }
    } else {
        $tree itemconfigure $node -image [Bitmap::get [lindex {folder openfold} $idx]]
    }
}


proc tree_select {num tree node} {
    variable dblclick
	
    set dblclick 1
    if { $num == 1 } {
            tree_select_node $tree $node
    }
}


proc tree_select_node {tree node} {
    global lf content ascii r_ascii r_hex e_input b_input
    $tree selection set $node
    update
    set dir [$tree itemcget $node -data]
    if { [$tree itemcget $node -drawcross] == "allways" } {
        tree_getdir $tree $node $dir
        set dir [$tree itemcget $node -data]
    }
    if {[file isfile $dir]} {
        $lf configure -text $dir
	empty_content $content
	if {[catch {set fid [open $dir r]}]==1} {
		tk_messageBox 	-icon error\
				-message "Wahrscheinlich unzureichende Rechte zum Oeffnen von $dir!"\
				-title "Fehler"\
				-type ok
	} else {
		$content configure -state normal
		if {$ascii} {
			ascii_output $fid $content		
		} else {
			hex_output $fid $content
		}
		$content configure -state disable
		close $fid
		$r_ascii configure -state normal
		$r_hex configure -state normal
		$e_input configure -state normal
		$b_input configure -state normal
	}
    } else {
        $lf configure -text "..."
	empty_content $content
    }
}


proc tree_expand { tree but } {
    if { [set cur [$tree selection get]] != "" } {
        if { $but == 0 } {
            $tree opentree $cur
        } else {
            $tree closetree $cur
        }
    }
}


proc ascii_output {fid content} {
	while {[gets $fid line] >= 0} {
       		$content insert end "$line\n"
	}
}


proc hex_output {fid content} {
    fconfigure $fid -translation binary
    set n 0
    while {![eof $fid]} {
        set bytes [read $fid 16]
        regsub -all {[^\x20-\xfe]} $bytes . ascii
        $content insert end [format "%08X %-48s %-16s" $n [hexdump $bytes] $ascii]
	$content insert end "\n"
        incr n 16
    }
 }
 

proc hexdump string {
    binary scan $string H* hex
    regexp -all -inline .. $hex
}


proc empty_content {content} {
	global r_ascii r_hex e_input b_input
	$content configure -state normal
	$content delete 1.0 end
	$content configure -state disable
	$r_ascii configure -state disable
	$r_hex configure -state disable
	$e_input configure -state disable
	$b_input configure -state disable
}

tree_init $tree
